==> aria2_1.16.1.orig.tar.bz2: aria2-1.16.1/src/metalink_helper.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_METALINK_HELPER_H
#define D_METALINK_HELPER_H

#include "common.h"

#include <string>
#include <vector>

#include "SharedHandle.h"
#include "A2STR.h"

namespace aria2 {

class Option;
class MetalinkEntry;
class BinaryStream;
class Metalinker;

namespace metalink {

void parseAndQuery
(std::vector<SharedHandle<MetalinkEntry> >& result,
 const std::string& filename,
 const Option* option,
 const std::string& baseUri = A2STR::NIL);

void parseAndQuery
(std::vector<SharedHandle<MetalinkEntry> >& result,
 BinaryStream* bs,
 const Option* option,
 const std::string& baseUri = A2STR::NIL);

void groupEntryByMetaurlName
(std::vector<
  std::pair<std::string, std::vector<SharedHandle<MetalinkEntry> > > >& result,
 const std::vector<SharedHandle<MetalinkEntry> >& entries);

SharedHandle<Metalinker> parseFile
(const std::string& filename,
 const std::string& baseUri = A2STR::NIL);

SharedHandle<Metalinker> parseBinaryStream
(BinaryStream* bs,
 const std::string& baseUri = A2STR::NIL);

} // namespace metalink

} // namespace aria2

#endif // D_METALINK_HELPER_H

==> aria2_1.18.8.orig.tar.bz2: aria2-1.18.8/src/metalink_helper.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_METALINK_HELPER_H
#define D_METALINK_HELPER_H

#include "common.h"

#include <string>
#include <vector>
#include <memory>

#include "A2STR.h"

namespace aria2 {

class Option;
class MetalinkEntry;
class BinaryStream;
class Metalinker;

namespace metalink {

std::vector<std::unique_ptr<MetalinkEntry>> parseAndQuery
(const std::string& filename,
 const Option* option,
 const std::string& baseUri = A2STR::NIL);

std::vector<std::unique_ptr<MetalinkEntry>> parseAndQuery
(BinaryStream* bs,
 const Option* option,
 const std::string& baseUri = A2STR::NIL);

std::vector<std::pair<std::string,
                      std::vector<MetalinkEntry*>>> groupEntryByMetaurlName
(const std::vector<std::unique_ptr<MetalinkEntry>>& entries);

std::unique_ptr<Metalinker> parseFile
(const std::string& filename,
 const std::string& baseUri = A2STR::NIL);

std::unique_ptr<Metalinker> parseBinaryStream
(BinaryStream* bs,
 const std::string& baseUri = A2STR::NIL);

} // namespace metalink

} // namespace aria2

#endif // D_METALINK_HELPER_H
